From xemacs-m  Thu Jul 10 10:13:33 1997
Received: from jagor.srce.hr (hniksic@jagor.srce.hr [161.53.2.130])
	by xemacs.org (8.8.5/8.8.5) with ESMTP id KAA07048
	for <xemacs-beta@xemacs.org>; Thu, 10 Jul 1997 10:13:31 -0500 (CDT)
Received: (from hniksic@localhost)
	by jagor.srce.hr (8.8.6/8.8.6) id RAA01018;
	Thu, 10 Jul 1997 17:13:30 +0200 (MET DST)
To: XEmacs Developers <xemacs-beta@xemacs.org>
Subject: Re: gnuserv.el enhancement - "Done" button
References: <26337.868545147@kocrsw12>
X-Attribution: Hrv
X-Face: Mie8:rOV<\c/~z{s.X4A{!?vY7{drJ([U]0O=W/<W*SMo/Mv:58:*_y~ki>xDi&N7XG
        KV^$k0m3Oe/)'e%3=$PCR&3ITUXH,cK>]bci&<qQ>Ff%x_>1`T(+M2Gg/fgndU%k*ft
        [(7._6e0n-V%|%'[c|q:;}td$#INd+;?!-V=c8Pqf}3J
From: Hrvoje Niksic <hniksic@srce.hr>
Date: 10 Jul 1997 17:13:30 +0200
In-Reply-To: Mike Scheidler's message of "Thu, 10 Jul 1997 09:32:27 -0500"
Message-ID: <kigpvsrc545.fsf@jagor.srce.hr>
Lines: 42
X-Mailer: Gnus v5.4.59/XEmacs 20.3(beta12) - "Helsinki"

Mike Scheidler <c23mts@eng.delcoelect.com> writes:

>   1.  Edit a file using gnuclient.  A new frame will be created.
>   2.  In the new frame, do a C-x C-f to edit another file.  The new
>       buffer will have a "Done" button that shouldn't be there.

I have managed to repeat it, thanks.  (and other people reported it,
too.)  This patch should fix it:


1997-07-10  Hrvoje Niksic  <hniksic@srce.hr>

	* packages/gnuserv.el (gnuserv-edit-files): Operate on this
	buffer's menubar.

--- lisp/packages/gnuserv.el.orig	Thu Jul 10 17:09:08 1997
+++ lisp/packages/gnuserv.el	Thu Jul 10 17:09:11 1997
@@ -1,7 +1,7 @@
 ;;; gnuserv.el --- Lisp interface code between Emacs and gnuserv
 ;; Copyright (C) 1989-1997 Free Software Foundation, Inc.
 
-;; Version: 3.8
+;; Version: 3.9
 ;; Author: Andy Norman (ange@hplb.hpl.hp.com), originally based on server.el
 ;;         Hrvoje Niksic <hniksic@srce.hr>
 ;; Maintainer: Jan Vroonhof <vroonhof@math.ethz.ch>,
@@ -445,7 +445,8 @@
 	  (unless (or quick view)
 	    (pushnew (current-buffer) (gnuclient-buffers client))
 	    (setq gnuserv-minor-mode t)
-	    ;; Add the "Done" button to the menubar.
+	    ;; Add the "Done" button to the menubar, only in this buffer.
+	    (set-buffer-menubar current-menubar)
 	    (add-menu-button nil ["Done" gnuserv-edit t]))
 	  (run-hooks 'gnuserv-visit-hook)
 	  (pop list)))


-- 
Hrvoje Niksic <hniksic@srce.hr> | Student at FER Zagreb, Croatia
--------------------------------+--------------------------------
Idle RAM is the Devil's playground.

